@@ -1,24 +1,16 @@
 from .core import TypusCore
-from .mixins import EnQuotes, EnRuExpressions, RuQuotes
+from .mixins import EnQuotes, EnRuExpressions, RuExpressions, RuQuotes
 from .processors import EscapeHtml, EscapePhrases, Expressions
 
 __all__ = ('en_typus', 'ru_typus')
 
 
-class BaseTypus(EnRuExpressions, TypusCore):
+class EnTypus(EnQuotes, EnRuExpressions, TypusCore):
     processors = (EscapePhrases, EscapeHtml, Expressions)
 
 
-class EnTypus(EnQuotes, BaseTypus):
-    """
-    TODO:
-    """
-
-
-class RuTypus(RuQuotes, BaseTypus):
-    """
-    TODO:
-    """
+class RuTypus(RuQuotes, RuExpressions, TypusCore):
+    processors = (EscapePhrases, EscapeHtml, Expressions)
 
 
 en_typus, ru_typus = EnTypus(), RuTypus()
