@@ -3,11 +3,15 @@ NNBSP = '\u202F'
 WHSP = ' '
 ANYSP = fr'[{WHSP}{NBSP}{NNBSP}]'
 
-NDASH = '–'
+NDASH = '–'  # Ctrl + "minus" on keyboard \u2013
 MDASH = '—'
 MDASH_PAIR = NBSP + MDASH + WHSP
 
-MINUS = '−'
+MINUS = '−'  # mathematical operator \u2212
+HYPHEN_MINUS = '-'  # "minus" on keyboard \u002D
+HYPHEN = '‐'  # \u2010
+NBHYPHEN = '‑'  # \u2011
+
 TIMES = '×'
 
 LSQUO = '‘'  # left curly quote mark
